import { EventEmitter, OnInit, ChangeDetectorRef, AfterViewInit, ElementRef } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import moment, { Moment, MomentBuiltinFormat } from 'moment-timezone';
import { CalendarDay } from './calendar-day.interface';
import { CalendarMonth } from './calendar-month.type';
import { CalendarView } from './calendar-view.enum';
import { CalendarSelect } from './calendar-select.enum';
import * as i0 from "@angular/core";
export interface CalendarDateRange {
    startDate: Date | undefined;
    endDate: Date | undefined;
}
export declare class CalendarComponent implements OnInit, AfterViewInit, ControlValueAccessor {
    private readonly cdr;
    private readonly elm;
    minDate: Date | string;
    disabled: boolean;
    maxDate: Date | string;
    daysOfWeek: string[];
    timezone: string;
    inputFormats: Array<string | MomentBuiltinFormat>;
    selectType: string;
    dateLabelFormat: string;
    range: CalendarDateRange;
    get minView(): CalendarView;
    set minView(val: CalendarView);
    get defaultView(): CalendarView;
    set defaultView(val: CalendarView);
    change: EventEmitter<Date>;
    onRangeSelect: EventEmitter<CalendarDateRange>;
    dayKeyEnter: EventEmitter<Date>;
    tabindex: number;
    get value(): Date;
    set value(val: Date);
    get current(): Moment;
    focusDate: Moment;
    weeks: CalendarMonth;
    currentView: CalendarView;
    monthsList: string[];
    startYear: number;
    startHour: string;
    endHour: string;
    startMinute: string;
    endMinute: string;
    startAmPmVal: string;
    endAmPmVal: string;
    readonly CalendarView: typeof CalendarView;
    readonly CalendarSelect: typeof CalendarSelect;
    private _value;
    private _current;
    private _minView;
    private _defaultView;
    constructor(cdr: ChangeDetectorRef, elm: ElementRef);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    changeViews(): void;
    validateView(): void;
    /**
     * Initializes the values for initial time
     */
    initializeTime(): void;
    /**
     * Checks if `date` matches selected value
     */
    isDayActive(date: Moment): boolean;
    /**
     * Checks if `date` matches the extreme ends of range
     */
    isDayRangeEnd(date: Moment): boolean;
    isDayRangeStart(date: Moment): boolean;
    isRangeStartActive(date: Moment): boolean;
    /**
     * Checks if `date` matches the extreme ends of range
     */
    isDayInRange(date: Moment): boolean;
    /**
     * Checks if `date` matches selected value
     */
    isDayFocus(date: Moment): boolean;
    /**
     * Checks if `month` matches selected value, in the viewed year
     */
    isMonthActive(month: string): boolean;
    /**
     * Checks if `month` and year matches current
     */
    isCurrentMonth(month: string): boolean;
    /**
     * Checks if `month` and year matches current focus
     */
    isFocusMonth(month: string): boolean;
    /**
     * Checks if `year` matches selected year
     */
    isYearActive(year: number): boolean;
    /**
     * Checks if year matches current year
     */
    isCurrentYear(year: number): boolean;
    /**
     * Checks if year matches current focus
     */
    isFocusYear(year: number): boolean;
    isDisabled(value: any, type: string): boolean;
    onDayClick(day: CalendarDay): void;
    onDaySelectRange(day: CalendarDay): void;
    onDayFocus(day: CalendarDay): void;
    onMonthClick(month: string): void;
    onYearClick(year: number): void;
    hourChanged(newVal: string, type: string): void;
    minuteChanged(newVal: string, type: string): void;
    onAmPmChange(newVal: any, type: any): void;
    prevMonth(): void;
    nextMonth(): void;
    prevYear(): void;
    nextYear(): void;
    moveFocus(amount: number, duration: moment.unitOfTime.DurationConstructor): void;
    setFocus(focusDate: Moment): void;
    prevTwoDecades(): void;
    nextTwoDecades(): void;
    writeValue(val: any): void;
    registerOnChange(fn: any): void;
    registerOnTouched(fn: any): void;
    onTouchedCallback: () => void;
    focus(): void;
    onDayDown(event: KeyboardEvent): void;
    onMonthDown(event: KeyboardEvent): void;
    onYearDown(event: KeyboardEvent): void;
    formatDate(date: Date): string;
    compareCalendarDays(date1: Date, date2: Date): boolean;
    private onChangeCallback;
    private parseDate;
    private createMoment;
    static ɵfac: i0.ɵɵFactoryDeclaration<CalendarComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CalendarComponent, "ngx-calendar", ["ngxCalendar"], { "minDate": { "alias": "minDate"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "maxDate": { "alias": "maxDate"; "required": false; }; "daysOfWeek": { "alias": "daysOfWeek"; "required": false; }; "timezone": { "alias": "timezone"; "required": false; }; "inputFormats": { "alias": "inputFormats"; "required": false; }; "selectType": { "alias": "selectType"; "required": false; }; "dateLabelFormat": { "alias": "dateLabelFormat"; "required": false; }; "range": { "alias": "range"; "required": false; }; "minView": { "alias": "minView"; "required": false; }; "defaultView": { "alias": "defaultView"; "required": false; }; }, { "change": "change"; "onRangeSelect": "onRangeSelect"; "dayKeyEnter": "dayKeyEnter"; }, never, never, false, never>;
}
