import { EventEmitter, TemplateRef, OnDestroy, ElementRef, ChangeDetectorRef, OnChanges, SimpleChanges } from '@angular/core';
import { ControlValueAccessor, UntypedFormControl, ValidationErrors, Validator } from '@angular/forms';
import moment from 'moment-timezone';
import { Clipboard } from '@angular/cdk/clipboard';
import { DialogService } from '../dialog/dialog.service';
import { Datelike } from './date-like.type';
import { InputComponent } from '../input/input.component';
import { NotificationService } from '../notification/notification.service';
import { Size } from '../../mixins/size/size.enum';
import { Appearance } from '../../mixins/appearance/appearance.enum';
import { DATE_DISPLAY_TYPES } from '../../enums/date-formats.enum';
import { CalendarComponent } from '../calendar/calendar.component';
import { TooltipDirective } from '../tooltip/tooltip.directive';
import * as i0 from "@angular/core";
export declare class DateTimeComponent implements OnDestroy, OnChanges, ControlValueAccessor, Validator {
    private readonly dialogService;
    private readonly cdr;
    private readonly clipboard;
    private readonly notificationService;
    id: string;
    name: string;
    label: string;
    hint: string;
    placeholder: string;
    size: Size;
    appearance: Appearance;
    withMargin: boolean;
    precision: moment.unitOfTime.StartOf;
    timezone: string;
    inputFormats: any[];
    set value(val: Date | string);
    get value(): Date | string;
    disabled: boolean;
    minWidth: number;
    tabindex: number;
    autofocus: boolean;
    set inputType(val: string);
    get inputType(): string;
    /**
     * Display mode for date/time
     * 'timezone' - display date/time with a timezone
     * 'local' - display date/time without timezone
     *
     * Defaults to LOCAL unless timezone is set
     */
    set displayMode(val: DATE_DISPLAY_TYPES);
    get displayMode(): DATE_DISPLAY_TYPES;
    /**
     * Display format for date/time
     * Considers if mode is user (has timezone), local (no timezone)
     */
    set format(val: string);
    get format(): string;
    set tooltipFormat(val: string);
    get tooltipFormat(): string;
    tooltipDisabled: boolean;
    get hasPopup(): boolean;
    dateInvalid: boolean;
    dateOutOfRange: boolean;
    /**
     * Used to display date in other timezones
     *
     * Only used if displayMode is 'user' or timezone is set
     */
    timezones: Record<string, string>;
    tooltipCssClass: string;
    set clipFormat(val: string);
    get clipFormat(): string;
    requiredIndicator: string | boolean;
    required: boolean;
    get displayValue(): string;
    set displayValue(value: string);
    autosize: boolean;
    minDate: Date | string;
    maxDate: Date | string;
    /**
     * this output will emit only when the input value is valid or cleared.
     */
    change: EventEmitter<string | Date>;
    /**
     * this output will emit anytime the value changes regardless of validity.
     */
    valueChange: EventEmitter<string | Date>;
    /**
     * this output will emit anytime the value changes in the input, regardless of validity.
     */
    inputChange: EventEmitter<string | Date>;
    /**
     * this output will emit a date is selected from the calendar
     */
    dateTimeSelected: EventEmitter<string | Date>;
    blur: EventEmitter<Event>;
    focus: EventEmitter<Event>;
    readonly calendarTpl: TemplateRef<ElementRef>;
    readonly input: InputComponent;
    readonly calendar: CalendarComponent;
    readonly tooltip: TooltipDirective;
    dialog: any;
    dialogModel: moment.Moment;
    hour: number;
    minute: string;
    second: string;
    millisecond: string;
    amPmVal: string;
    modes: string[];
    timeValues: {};
    private _value;
    private _displayValue;
    private _format;
    private _tooltipFormat;
    private _inputType;
    private _displayMode;
    private _clipFormat;
    private _focused;
    constructor(dialogService: DialogService, cdr: ChangeDetectorRef, clipboard: Clipboard, notificationService: NotificationService);
    ngOnDestroy(): void;
    ngOnChanges(changes: SimpleChanges): void;
    writeValue(val: any): void;
    onFocus(event?: Event): void;
    onBlur(event?: Event): void;
    open(): void;
    apply(): void;
    setDialogDate(date: Datelike): void;
    minuteChanged(newVal: number): void;
    secondChanged(newVal: number): void;
    millisecondChanged(newVal: number): void;
    hourChanged(newVal: number): void;
    selectCurrent(): void;
    isCurrent(): boolean;
    clear(): void;
    onAmPmChange(newVal: string): void;
    getDayDisabled(date: moment.Moment): boolean;
    isTimeDisabled(mode: moment.unitOfTime.StartOf): boolean;
    inputChanged(val: string): void;
    close(): void;
    registerOnChange(fn: any): void;
    registerOnTouched(fn: any): void;
    onClick(item: any): void;
    validate(c: UntypedFormControl): ValidationErrors | null;
    setDisabledState(isDisabled: boolean): void;
    onTouchedCallback: () => void;
    onChangeCallback: (_: any) => void;
    onInputKeyDown(event: KeyboardEvent): void;
    private roundTo;
    private parseDate;
    private createMoment;
    private update;
    static ɵfac: i0.ɵɵFactoryDeclaration<DateTimeComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DateTimeComponent, "ngx-date-time", ["ngxDateTime"], { "id": { "alias": "id"; "required": false; }; "name": { "alias": "name"; "required": false; }; "label": { "alias": "label"; "required": false; }; "hint": { "alias": "hint"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "size": { "alias": "size"; "required": false; }; "appearance": { "alias": "appearance"; "required": false; }; "withMargin": { "alias": "withMargin"; "required": false; }; "precision": { "alias": "precision"; "required": false; }; "timezone": { "alias": "timezone"; "required": false; }; "inputFormats": { "alias": "inputFormats"; "required": false; }; "value": { "alias": "value"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "minWidth": { "alias": "minWidth"; "required": false; }; "tabindex": { "alias": "tabindex"; "required": false; }; "autofocus": { "alias": "autofocus"; "required": false; }; "inputType": { "alias": "inputType"; "required": false; }; "displayMode": { "alias": "displayMode"; "required": false; }; "format": { "alias": "format"; "required": false; }; "tooltipFormat": { "alias": "tooltipFormat"; "required": false; }; "tooltipDisabled": { "alias": "tooltipDisabled"; "required": false; }; "timezones": { "alias": "timezones"; "required": false; }; "tooltipCssClass": { "alias": "tooltipCssClass"; "required": false; }; "clipFormat": { "alias": "clipFormat"; "required": false; }; "requiredIndicator": { "alias": "requiredIndicator"; "required": false; }; "required": { "alias": "required"; "required": false; }; "autosize": { "alias": "autosize"; "required": false; }; "minDate": { "alias": "minDate"; "required": false; }; "maxDate": { "alias": "maxDate"; "required": false; }; }, { "change": "change"; "valueChange": "valueChange"; "inputChange": "inputChange"; "dateTimeSelected": "dateTimeSelected"; "blur": "blur"; "focus": "focus"; }, never, never, false, never>;
}
