import { AfterViewInit, OnDestroy, ElementRef, EventEmitter, ChangeDetectorRef } from '@angular/core';
import { ControlValueAccessor, Validator, NgModel, UntypedFormControl, ValidationErrors } from '@angular/forms';
import { BehaviorSubject } from 'rxjs';
import { Appearance } from '../../mixins/appearance/appearance.enum';
import { InputTypes } from './input-types.enum';
import { Size } from '../../mixins/size/size.enum';
import * as i0 from "@angular/core";
export declare class InputComponent implements AfterViewInit, OnDestroy, ControlValueAccessor, Validator {
    private readonly cdr;
    id: string;
    name: string;
    label: string;
    hint: string;
    placeholder: string;
    tabindex: number;
    min: number;
    max: number;
    minlength: number;
    maxlength: number;
    size: Size;
    appearance: Appearance;
    withMargin: boolean;
    textareaRows: number;
    get disabled(): boolean;
    set disabled(disabled: boolean);
    get readonly(): boolean;
    set readonly(readonly: boolean);
    get minWidth(): number;
    set minWidth(minWidth: number);
    requiredIndicator: string | boolean;
    get required(): boolean;
    set required(required: boolean);
    passwordToggleEnabled: boolean;
    get passwordTextVisible(): boolean;
    set passwordTextVisible(p: boolean);
    get autoSelect(): boolean;
    set autoSelect(autoSelect: boolean);
    get autofocus(): boolean;
    set autofocus(autofocus: boolean);
    get autocomplete(): boolean | string;
    set autocomplete(autocomplete: boolean | string);
    get autocorrect(): boolean;
    set autocorrect(autocorrect: boolean);
    get spellcheck(): boolean;
    set spellcheck(spellcheck: boolean);
    get type(): InputTypes;
    set type(type: InputTypes);
    get autosize(): boolean;
    set autosize(v: boolean);
    get unlockable(): boolean;
    set unlockable(v: boolean);
    unlockableTooltip: string;
    change: EventEmitter<string | number>;
    blur: EventEmitter<Event>;
    focus: EventEmitter<FocusEvent>;
    keyup: EventEmitter<KeyboardEvent>;
    click: EventEmitter<Event>;
    select: EventEmitter<FocusEvent>;
    lockChange: EventEmitter<boolean>;
    readonly inputControl: ElementRef<HTMLInputElement>;
    readonly inputModel: NgModel;
    readonly textareaControl: ElementRef<HTMLTextAreaElement>;
    get value(): string | number;
    set value(val: string | number);
    get valueAsString(): string;
    get valueAsNumber(): number;
    get focusedOrDirty(): any;
    get isBadInput(): boolean;
    get isTouched(): boolean;
    get hasPlaceholder(): boolean;
    get labelState(): boolean;
    get underlineState(): string;
    get element(): ElementRef<HTMLInputElement> | ElementRef<HTMLTextAreaElement>;
    focused: boolean;
    readonly type$: BehaviorSubject<InputTypes>;
    readonly inputTypes: typeof InputTypes;
    private _value;
    private _type;
    private _passwordTextVisible;
    private _disabled;
    private _readonly;
    private _required;
    private _autoSelect;
    private _autofocus;
    private _autocomplete;
    private _autocorrect;
    private _spellcheck;
    private _autosize;
    private _spinnerInterval;
    private _spinnerTimeout;
    private _minWidth;
    private _unlockable;
    constructor(cdr: ChangeDetectorRef);
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    onChange(event: Event): void;
    onKeyUp(event: KeyboardEvent): void;
    onFocus(event: FocusEvent): void;
    onBlur(event: Event): void;
    validate(c: UntypedFormControl): ValidationErrors | null;
    writeValue(val: string): void;
    registerOnChange(fn: any): void;
    registerOnTouched(fn: any): void;
    togglePassword(): void;
    setDisabledState(isDisabled: boolean): void;
    unlock(): void;
    incrementValue(event: MouseEvent): void;
    decrementValue(event: MouseEvent): void;
    clearSpinnerInterval(): void;
    private onTouchedCallback;
    private onChangeCallback;
    private updateInputType;
    private increment;
    private decrement;
    static ɵfac: i0.ɵɵFactoryDeclaration<InputComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<InputComponent, "ngx-input", ["ngxInput"], { "id": { "alias": "id"; "required": false; }; "name": { "alias": "name"; "required": false; }; "label": { "alias": "label"; "required": false; }; "hint": { "alias": "hint"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "tabindex": { "alias": "tabindex"; "required": false; }; "min": { "alias": "min"; "required": false; }; "max": { "alias": "max"; "required": false; }; "minlength": { "alias": "minlength"; "required": false; }; "maxlength": { "alias": "maxlength"; "required": false; }; "size": { "alias": "size"; "required": false; }; "appearance": { "alias": "appearance"; "required": false; }; "withMargin": { "alias": "withMargin"; "required": false; }; "textareaRows": { "alias": "textareaRows"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "readonly": { "alias": "readonly"; "required": false; }; "minWidth": { "alias": "minWidth"; "required": false; }; "requiredIndicator": { "alias": "requiredIndicator"; "required": false; }; "required": { "alias": "required"; "required": false; }; "passwordToggleEnabled": { "alias": "passwordToggleEnabled"; "required": false; }; "passwordTextVisible": { "alias": "passwordTextVisible"; "required": false; }; "autoSelect": { "alias": "autoSelect"; "required": false; }; "autofocus": { "alias": "autofocus"; "required": false; }; "autocomplete": { "alias": "autocomplete"; "required": false; }; "autocorrect": { "alias": "autocorrect"; "required": false; }; "spellcheck": { "alias": "spellcheck"; "required": false; }; "type": { "alias": "type"; "required": false; }; "autosize": { "alias": "autosize"; "required": false; }; "unlockable": { "alias": "unlockable"; "required": false; }; "unlockableTooltip": { "alias": "unlockableTooltip"; "required": false; }; }, { "change": "change"; "blur": "blur"; "focus": "focus"; "keyup": "keyup"; "click": "click"; "select": "select"; "lockChange": "lockChange"; }, never, ["ngx-input-prefix", "ngx-input-suffix", "ngx-input-hint"], false, never>;
}
