import { ChangeDetectorRef, ElementRef, EventEmitter, OnDestroy, Renderer2, TemplateRef } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import type { QueryList } from '@angular/core';
import { Appearance } from '../../mixins/appearance/appearance.enum';
import { SelectDropdownOption } from './select-dropdown-option.interface';
import { SelectDropdownComponent } from './select-dropdown.component';
import { SelectInputComponent } from './select-input.component';
import { SelectOptionDirective } from './select-option.directive';
import * as i0 from "@angular/core";
declare const _InputMixinBase: any;
export declare class SelectComponent extends _InputMixinBase implements ControlValueAccessor, OnDestroy {
    private readonly _element;
    private readonly _renderer;
    private readonly _cdr;
    id: string;
    name: string;
    label: string;
    hint: string;
    placeholder: string;
    emptyPlaceholder: string;
    filterEmptyPlaceholder: string;
    filterPlaceholder: string;
    forceDownwardOpening: boolean;
    allowAdditionsText: string;
    groupBy: string;
    selectCaret: string;
    requiredIndicator: string | boolean;
    options: SelectDropdownOption[];
    identifier: string;
    appearance: Appearance;
    minSelections?: number;
    maxSelections?: number;
    get autosizeMinWidth(): number | string;
    set autosizeMinWidth(autosizeMinWidth: number | string);
    autofocus: boolean;
    autosize: boolean;
    allowClear: boolean;
    allowAdditions: boolean;
    disableDropdown: boolean;
    closeOnSelect: boolean;
    closeOnBodyClick: boolean;
    filterable: boolean;
    required: boolean;
    filterCaseSensitive: boolean;
    tagging: boolean;
    multiple: boolean;
    disabled: boolean;
    change: EventEmitter<any[]>;
    keyup: EventEmitter<{
        event: KeyboardEvent;
        value?: string;
    }>;
    toggle: EventEmitter<boolean>;
    clearQueryFilter: EventEmitter<void>;
    readonly inputComponent: SelectInputComponent;
    readonly selectDropdown: SelectDropdownComponent;
    /**
     * Custom Template for groupBy
     * Only works with groupBy on
     *
     * TemplateContext:
     * - groupName: the name of the group (`option.value[this.groupBy]` is the value)
     * - index, first, last, odd, even (ngFor properties)
     */
    groupByTemplate: TemplateRef<unknown>;
    get optionTemplates(): QueryList<SelectOptionDirective>;
    set optionTemplates(val: QueryList<SelectOptionDirective>);
    get invalid(): boolean;
    get requiredIndicatorView(): string;
    get isSingleSelect(): boolean;
    get hasSelections(): boolean;
    get hasPlaceholder(): boolean;
    get value(): any[];
    set value(val: any[]);
    get dropdownVisible(): boolean;
    toggleListener?: () => void;
    filterQuery: string;
    focusIndex: number;
    dropdownActive: boolean;
    touched: boolean;
    private _optionTemplates;
    private _value;
    private _autosizeMinWidth;
    constructor(_element: ElementRef, _renderer: Renderer2, _cdr: ChangeDetectorRef);
    ngOnDestroy(): void;
    onDropdownSelection(selection: SelectDropdownOption, shouldClose?: boolean): void;
    onDropdownDeselection(selection: SelectDropdownOption, shouldClose?: boolean): void;
    private afterSelect;
    onInputSelection(selections: any[]): void;
    onFocus(): void;
    onFocusLast(): void;
    focusOn(index: number): void;
    onClear(): void;
    onBodyClick(event: Event): void;
    onClose(keepFocus?: boolean): void;
    onToggle(): void;
    toggleDropdown(state: boolean): void;
    onKeyUp({ event, value }: {
        event: KeyboardEvent;
        value?: string;
    }): void;
    writeValue(val: any[]): void;
    registerOnChange(fn: any): void;
    registerOnTouched(fn: any): void;
    setDisabledState(isDisabled: boolean): void;
    private findIndex;
    private adjustMenuDirection;
    private isIntersectingBottom;
    private isIntersectingTop;
    private checkInvalidValue;
    private onChangeCallback;
    private onTouchedCallback;
    static ɵfac: i0.ɵɵFactoryDeclaration<SelectComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SelectComponent, "ngx-select", ["ngxSelect"], { "id": { "alias": "id"; "required": false; }; "name": { "alias": "name"; "required": false; }; "label": { "alias": "label"; "required": false; }; "hint": { "alias": "hint"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "emptyPlaceholder": { "alias": "emptyPlaceholder"; "required": false; }; "filterEmptyPlaceholder": { "alias": "filterEmptyPlaceholder"; "required": false; }; "filterPlaceholder": { "alias": "filterPlaceholder"; "required": false; }; "forceDownwardOpening": { "alias": "forceDownwardOpening"; "required": false; }; "allowAdditionsText": { "alias": "allowAdditionsText"; "required": false; }; "groupBy": { "alias": "groupBy"; "required": false; }; "selectCaret": { "alias": "selectCaret"; "required": false; }; "requiredIndicator": { "alias": "requiredIndicator"; "required": false; }; "options": { "alias": "options"; "required": false; }; "identifier": { "alias": "identifier"; "required": false; }; "appearance": { "alias": "appearance"; "required": false; }; "minSelections": { "alias": "minSelections"; "required": false; }; "maxSelections": { "alias": "maxSelections"; "required": false; }; "autosizeMinWidth": { "alias": "autosizeMinWidth"; "required": false; }; "autofocus": { "alias": "autofocus"; "required": false; }; "autosize": { "alias": "autosize"; "required": false; }; "allowClear": { "alias": "allowClear"; "required": false; }; "allowAdditions": { "alias": "allowAdditions"; "required": false; }; "disableDropdown": { "alias": "disableDropdown"; "required": false; }; "closeOnSelect": { "alias": "closeOnSelect"; "required": false; }; "closeOnBodyClick": { "alias": "closeOnBodyClick"; "required": false; }; "filterable": { "alias": "filterable"; "required": false; }; "required": { "alias": "required"; "required": false; }; "filterCaseSensitive": { "alias": "filterCaseSensitive"; "required": false; }; "tagging": { "alias": "tagging"; "required": false; }; "multiple": { "alias": "multiple"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "groupByTemplate": { "alias": "groupByTemplate"; "required": false; }; }, { "change": "change"; "keyup": "keyup"; "toggle": "toggle"; "clearQueryFilter": "clearQueryFilter"; }, ["optionTemplates"], never, false, never>;
}
export {};
